@@ -49,17 +49,11 @@ class MyHook(cgitb.Hook):
 NOTFOUND = []
 
 try:
-    from qt import Qt, QEvent, QMetaObject, QTimer
+    from qt import Qt, QEvent, QMetaObject, QTimer, QKeySequence
     from qt import QWidget, QGridLayout, QAction
 except ImportError as importError:
     NOTFOUND.append('Please install PyQt5: %s' % importError)
 
-try:
-    from zope.interface import implements  # pylint: disable=unused-import
-except ImportError as importError:
-    NOTFOUND.append('Package python-zope-interface missing: %s' % importError)
-
-
 try:
     from twisted.spread import pb # pylint: disable=unused-import
     from twisted.internet.error import ReactorNotRunning
@@ -85,7 +79,7 @@ try:
     from configdialog import ConfigDialog
     from statesaver import StateSaver
     from util import checkMemory
-    from kdestub import Action
+    from kdestub import Action, KApplication
 
 except ImportError as importError:
     NOTFOUND.append('Kajongg is not correctly installed: modules: %s' %
@@ -203,7 +197,7 @@ class MainWindow(KXmlGuiWindow):
                         # we want space to the right for the buttons
         # the default is too small. Use at least 2/3 of screen height and 1/2
         # of screen width:
-        available = Internal.app.desktop().availableGeometry()
+        available = KApplication.desktopSize()
         height = max(result.height(), available.height() * 2 // 3)
         width = max(result.width(), available.width() // 2)
         result.setHeight(height)
@@ -299,7 +293,7 @@ class MainWindow(KXmlGuiWindow):
             Qt.Key_E, actionData=ExplainView)
         self.actionExplain.setEnabled(False)
         self.actionFullscreen = self._kajonggToggleAction(
-            "fullscreen", "view-fullscreen", shortcut=Qt.Key_F + Qt.ShiftModifier)
+            "fullscreen", "view-fullscreen", shortcut=Qt.Key_F | Qt.ShiftModifier)
         self.actionFullscreen.toggled.connect(self.fullScreen)
         self.actionAutoPlay = Action(
             self,
@@ -475,6 +469,9 @@ class MainWindow(KXmlGuiWindow):
         else:
             if Debug.quit:
                 logDebug('aboutToQuit: mainWindow is already None')
+            # this does not happen with PyQt5/6 or PySide2, only with PySide6
+            # return here to avoid recursion in StateSaver
+            return
         StateSaver.saveAll()
         Internal.app.quit()
         try:
