@@ -3,19 +3,8 @@
 """
 Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-Kajongg is free software you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation either version 2 of the License, or
-(at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
 import weakref
@@ -76,8 +65,7 @@ class Move(StrMixin):
     @property
     def player(self):
         """hide weakref"""
-        if self._player:
-            return self._player()
+        return self._player() if self._player else None
 
     @staticmethod
     def prettyKwargs(kwargs):
