@@ -4,23 +4,10 @@
 """
 Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-Kajongg is free software you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation either version 2 of the License, or
-(at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
-from __future__ import print_function
-
 import unittest
 
 from common import Debug  # pylint: disable=unused-import
@@ -46,8 +33,7 @@ for _ in RULESETS[2:]:
 Players.createIfUnknown = str
 
 # RULESETS=RULESETS[:1]
-GAMES = list([PlayingGame(list(tuple([wind, str(wind.char)]) for wind in Wind.all4), x)
-              for x in RULESETS])
+GAMES = [PlayingGame([tuple([wind, str(wind.char)]) for wind in Wind.all4], x) for x in RULESETS]
 PROGRAM = None
 
 
@@ -60,10 +46,7 @@ class Expected:
         self.score = Score(points, doubles, limits)
 
     def __str__(self):
-        if self.won:
-            return 'Won with %s' % self.score
-        else:
-            return 'Lost with %s' % self.score
+        return 'Won with %s' % self.score if self.won else 'Lost with %s' % self.score
 
 
 class Win(Expected):
@@ -136,7 +119,7 @@ class Helpers:
             game.players[0].clearCache()
             hand = Hand(game.players[0], string)
             testSays = TileList(
-                set(x.lastTile.exposed for x in hand.callingHands)).sorted()
+                {x.lastTile.exposed for x in hand.callingHands}).sorted()
             if isinstance(expected, list):
                 if idx >= len(expected):
                     idx %= len(RULESETS) // 2
@@ -722,11 +705,11 @@ class Blessing(Base):
     """blessing of heaven or earth"""
 
     def testMe(self):
-        self.scoreTest('s4s5s6 RS1S2S3B6B6B7B7B8B8 b5b5 fn yn m1 LS1S1S2S3',
+        self.scoreTest('s4s5s6 RS1S2S3B6B6B7B7B8B8 b5b5 fn yn m1',
                        [Win(limits=1), NoWin()])
-        self.scoreTest('s4s5s6 RS1S2S3B6B6B7B7B8B8 b5b5 fn yn m1 LS1S1S2S3',
+        self.scoreTest('s4s5s6 RS1S2S3B6B6B7B7B8B8 b5b5 fn yn m1',
                        [Win(limits=1), NoWin()])
-        self.scoreTest('s4s5s6 RS1S1S1B6B6B6B8B8B8 b5b5 fn yn m1 LS1S1S1S1',
+        self.scoreTest('s4s5s6 RS1S1S1B6B6B6B8B8B8 b5b5 fn yn m1',
                        Win(limits=1))
         self.scoreTest('s4s5s6 RS1S2S3B6B6B7B7B8B8 b5b5 fn yn m1 Ls4s4s5s6',
                        [Win(limits=1), NoWin()], myWind=West)
