@@ -4,19 +4,8 @@ Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 partially based on C++ code from:
 Copyright (C) 2006 Mauricio Piacentini <mauricio@tabuleiro.com>
 
-Libkmahjongg is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
 from qt import QWidget, QHBoxLayout, QLineEdit
@@ -35,7 +24,7 @@ class TilesetSelector(QWidget):
     """presents all available tiles with previews"""
 
     def __init__(self, parent):
-        super(TilesetSelector, self).__init__(parent)
+        super().__init__(parent)
 
         loadUi(self)
         self.kcfg_tilesetName = QLineEdit(self)
